Index: main/groovy/org/gradle/groovy/scripts/DefaultCachePropertiesHandler.java
===================================================================
--- main/groovy/org/gradle/groovy/scripts/DefaultCachePropertiesHandler.java	(revision 1248)
+++ main/groovy/org/gradle/groovy/scripts/DefaultCachePropertiesHandler.java	(working copy)
@@ -46,15 +46,20 @@
         if (!propertiesFile.isFile()) {
             return CacheState.INVALID;
         }
+        if(scriptText == null || scriptText.length()==0) {
+            return CacheState.EMPTY_SCRIPT;
+        }
         Properties properties = GUtil.loadProperties(new File(scriptCacheDir, CachePropertiesHandler.PROPERTY_FILE_NAME));
+
+        boolean markedAsEmpty = false;
         if (properties.get(CachePropertiesHandler.EMPTY_SCRIPT) != null && properties.get(CachePropertiesHandler.EMPTY_SCRIPT).equals(Boolean.TRUE.toString())) {
-            return CacheState.EMPTY_SCRIPT;
+            markedAsEmpty = true;
         }
         if (!properties.get(CachePropertiesHandler.VERSION_KEY).equals(new GradleVersion().getVersion())) {
             return CacheState.INVALID;
         }
         return createHash(scriptText).equals(properties.get(CachePropertiesHandler.HASH_KEY)) ?
-                CacheState.VALID : CacheState.INVALID;
+                (markedAsEmpty? CacheState.EMPTY_SCRIPT : CacheState.VALID ) : CacheState.INVALID;
     }
 
     private String createHash(String scriptText) {
Index: test/groovy/org/gradle/groovy/scripts/DefaultCachePropertiesHandlerTest.java
===================================================================
--- test/groovy/org/gradle/groovy/scripts/DefaultCachePropertiesHandlerTest.java	(revision 1248)
+++ test/groovy/org/gradle/groovy/scripts/DefaultCachePropertiesHandlerTest.java	(working copy)
@@ -41,7 +41,9 @@
  * @author Hans Dockter
  */
 public class DefaultCachePropertiesHandlerTest {
-    public static final String TEST_SCRIPT_TEXT = "someScript";
+    public static final String OLD_TEST_SCRIPT_TEXT = "oldScript";
+    public static final String TEST_SCRIPT_TEXT     = "someScript";
+    public static final String EMPTY_SCRIPT_TEXT    = null;
 
     private DefaultCachePropertiesHandler cachePropertyHandler;
 
@@ -88,11 +90,23 @@
     }
 
     @Test
-    public void getCacheStateWithEmptyScript() throws NoSuchAlgorithmException, IOException {
+    public void getCacheStateWithEmptyScriptPreviouslyEmpty() throws NoSuchAlgorithmException, IOException {
         createPropertiesFile(TEST_SCRIPT_TEXT, true, new GradleVersion().getVersion());
-        assertEquals(CachePropertiesHandler.CacheState.EMPTY_SCRIPT, cachePropertyHandler.getCacheState(TEST_SCRIPT_TEXT, testCacheDir));
+        assertEquals(CachePropertiesHandler.CacheState.EMPTY_SCRIPT, cachePropertyHandler.getCacheState(EMPTY_SCRIPT_TEXT, testCacheDir));
     }
 
+    @Test
+    public void getCacheStateWithEmptyScriptPreviouslyNotEmpty() throws NoSuchAlgorithmException, IOException {
+        createPropertiesFile(TEST_SCRIPT_TEXT, false, new GradleVersion().getVersion());
+        assertEquals(CachePropertiesHandler.CacheState.EMPTY_SCRIPT, cachePropertyHandler.getCacheState(EMPTY_SCRIPT_TEXT, testCacheDir));
+    }
+
+    @Test
+    public void getCacheStateWithNotEmptyScriptPreviouslyEmpty() throws NoSuchAlgorithmException, IOException {
+        createPropertiesFile(OLD_TEST_SCRIPT_TEXT, true, new GradleVersion().getVersion());
+        assertEquals(CachePropertiesHandler.CacheState.INVALID, cachePropertyHandler.getCacheState(TEST_SCRIPT_TEXT, testCacheDir));
+    }
+
     private void createPropertiesFile(String scriptText, boolean emptyScript, String version) throws NoSuchAlgorithmException, IOException {
         Properties properties = new Properties();
         properties.put(CachePropertiesHandler.HASH_KEY, createHash(scriptText));
